Class: Para::Admin::BaseController
- Inherits:
-
Para::ApplicationController
- Object
- ActionController::Base
- Para::ApplicationController
- Para::Admin::BaseController
- Includes:
- BaseHelper
- Defined in:
- app/controllers/para/admin/base_controller.rb
Direct Known Subclasses
Class Method Summary collapse
-
.cancan_resource_class ⇒ Object
Override cancan controlelr resource class to avoid attributes assignation issues with resources.
- .load_and_authorize_component(options = {}) ⇒ Object
Instance Method Summary collapse
Methods included from BaseHelper
#find_partial_for, #find_relation_name_for, #flash_message, #registered_components_options, #resource_title_for, #template_path_lookup
Methods included from Helpers::ResourceName
Methods inherited from Para::ApplicationController
Class Method Details
.cancan_resource_class ⇒ Object
Override cancan controlelr resource class to avoid attributes assignation issues with resources
38 39 40 |
# File 'app/controllers/para/admin/base_controller.rb', line 38 def self.cancan_resource_class Para::ControllerResource end |
.load_and_authorize_component(options = {}) ⇒ Object
46 47 48 49 50 |
# File 'app/controllers/para/admin/base_controller.rb', line 46 def self.( = {}) before_action do () end end |